#
# spec file for package xfce4-systemload-plugin
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.12.0
%define plugin systemload
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        1.3.1
Release:        bp153.2.3.1
Summary:        System Load Monitoring Plugin for the Xfce Panel
License:        BSD-2-Clause
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-systemload-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/1.3/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= %{panel_version}
BuildRequires:  pkgconfig(upower-glib)
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Requires:       xfce4-panel >= %{panel_version}
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The Systemload plugin can display the current CPU load, used memory and swap
space as well as the system uptime in the panel.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode \
  --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install

rm %{buildroot}%{_libdir}/xfce4/panel/plugins/libsystemload.la

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%clean
rm -rf %{buildroot}

%files
%doc AUTHORS NEWS README.md
%license COPYING
%{_libdir}/xfce4/panel/plugins/libsystemload.so
%{_datadir}/xfce4/panel/plugins/systemload.desktop
%{_datadir}/icons/hicolor/*/apps/org.xfce.panel.systemload.*

%files lang -f %{name}.lang

%changelog
* Tue Mar 23 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.3.1
  * Update README.md
  * Update and sort the list of authors
  * Add a simple network bandwidth monitor (uses libgtop as a fallback)
  * Remove 4-valued history
  * Fix initial progress bar value
  * Fix system-monitor-command setting
    (gxo#panel-plugins/xfce4-systemload-plugin#15)
  * Distinguish uptime from the appearance of a digital real-time clock
  * Replace "Options" with "Label" in the properties dialog
  * Finish porting to xfconf
  * Update docs URL
  * Code cleanups
  * Translation Updates
* Thu Mar 11 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.3.0
  * Port to xfconf
  * Add new icons and switch to rDNS naming
  * Add Help button to properties dialog
  * Fix compilation warnings
  * autoconf: Some updates
  * Update `.gitignore`
  * configure.ac: use AC_PROG_CC_C99
  * Translation Updates
* Mon Dec 21 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Updat to version 1.2.4
  * Allow compilation with panel 4.15+
  * Fix missing-prototypes
  * Remove GSourceFunc casts
  * Fix the properties dialog and a hidden memory corruption
  * Avoid repainting bars if there are no visual changes
  * Update copyright year
  * Update URLs
  * Create README.md and update configure.ac.in
  * Add basic GitLab pipeline
  * Update URLs from goodies.x.o to docs.x.o (bxo#16178)
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed source in spec file
* Wed Aug 14 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.2.3
  * fix possible leak
  * fix a crash when opening the properties dialog
  * translation updates
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
- Move COPYING under %%license macro
* Wed Jan  2 2019 Maurizio Galli <maurizio.galli@gmail.com>
- update to version 1.2.2:
  - general rework of the preferences dialog by our resident UI wizard
    Simon Steinbeiss
  - fix the 'no tooltips' regression by setting the default update
    interval to 0.5s (workaround for bxo#13536)
  - tons of translation updates
* Wed Apr 19 2017 seife+obs@b1-systems.com
- update to version 1.2.1:
  - rework sizing of the progressbar (bxo#12948, bxo#12974)
  - rework the use of GtkCssProvider to use a singleton
  - fix progressbar color with Gtk 3.16/3.18
  - translation updates
* Sun Nov 27 2016 seife+obs@b1-systems.com
- update to version 1.2.0:
  - port to gtk+3/libxfce4ui-2/libxfce4panel-2.0
  - use MemAvailable on Linux 3.14+
- do not package ChangeLog; NEWS file is good enough
* Fri Nov 21 2014 gber@opensuse.org
- update to version 1.1.2
  - support upower 0.99
  - add a way to run a command when clicking on systemload plugin
  - pick up translation updates & fixes, especially DE locale
  - merge some OpenBSD compatibility patches
- drop obsolete xfce4-panel-plugin-systemload-upower-0.99.patch,
  xfce4-systemload-plugin-russian.patch
* Tue Jun 10 2014 gber@opensuse.org
- Add xfce4-panel-plugin-systemload-upower-0.99.patch in order to
  support upower >= 0.99 (bxo#10923)
* Fri May 31 2013 lazy.kent@opensuse.org
- Add xfce4-systemload-plugin-russian.patch: fix Russian
  translation (plural forms and one string).
* Sun Jul  1 2012 gber@opensuse.org
- update to version 1.1.1
  - simplify tooltip handling code
  - better compliance with panel plugin HIG
  - only set label angle with panel > 4.9
  - set plugin to small in all modes except deskbar modes
  - facilitate bringing up the configuration dialog
  - fix background transparency by setting the main evbox hidden
  - changing uptime label orientation in the vertical mode
  - compatibility with panel 4.9+
* Fri Apr 20 2012 gber@opensuse.org
- corrected license
* Wed Apr 18 2012 gber@opensuse.org
- update to version 1.1.0
  - fix progressbar width in vertical mode
  - added about dialog
  - use a single label to show uptime, either 'X days' (if > 0) or
    'hh:mm'
  - build the plugin as a module
  - added a power-saving interval option using upower (if present
    at build time)
  - added an update interval option
  - rewritten configuration dialog
  - conditional retrieval of system stats
  - port to libxfce4ui
  - fix transparency issues
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Wed Apr  4 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- split off -lang subpackage
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
